docs.rs failed to build ossl-sys-1.5.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
ossl-sys
A crate providing low-level Rust bindings to the OpenSSL library.
ossl-sys was spun off from the ossl crate to provide unsafe low-level
FFI bindings. It is intended as a foundational building block for
higher-level cryptographic libraries rather than for direct application use.